Object.defineProperty(exports, '__esModule', { value: true });

var reactHookForm = require('react-hook-form');
var React = require('react');
var core = require('@material-ui/core');
var icons = require('@material-ui/icons');
var reactIntl = require('react-intl');
var reactCrudComponents = require('@crud-studio/react-crud-components');
var reactCrudCore = require('@crud-studio/react-crud-core');
var reactUse = require('react-use');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

var InputUtils = {
    inputRemoveWhitespaces: function (e) {
        var value = e.target.value;
        e.target.value = value.replace(/\s/g, "");
    },
    inputRemoveNonDigits: function (e) {
        var value = e.target.value;
        e.target.value = value.replace(/[^0-9]/gi, "");
    },
};

function useLoginEmailPassword(email, password) {
    return reactCrudCore.useGenericRequest({
        url: "/auth/login/EmailPassword",
        method: "POST",
        data: {
            email: email,
            password: password,
        },
    }, {
        manual: true,
    });
}

var LoginEmailPasswordCard = function (_a) {
    var logoSrc = _a.logoSrc, logoUrl = _a.logoUrl, logoHeight = _a.logoHeight, titleKey = _a.titleKey, subtitleKey = _a.subtitleKey, onLoginSuccess = _a.onLoginSuccess;
    var intl = reactIntl.useIntl();
    var _b = reactHookForm.useForm({
        mode: "onBlur",
        reValidateMode: "onChange",
    }), handleSubmit = _b.handleSubmit, control = _b.control, errors = _b.formState.errors;
    var email = reactHookForm.useWatch({ control: control, name: "email", defaultValue: "" });
    var password = reactHookForm.useWatch({ control: control, name: "password", defaultValue: "" });
    var loginState = useLoginEmailPassword(email, password);
    reactUse.useUpdateEffect(function () {
        if (loginState.result) {
            onLoginSuccess(loginState.result);
        }
    }, [loginState.result]);
    var onSubmit = handleSubmit(function (data) {
        loginState.executeRequest();
    });
    return (React__default['default'].createElement(core.Paper, { variant: "elevation", sx: {
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
            p: 4,
        } },
        React__default['default'].createElement(core.Box, { sx: { mb: 2 } }, !!logoSrc ? (React__default['default'].createElement(reactCrudComponents.ConditionalLink, { to: logoUrl || "/", condition: !!logoUrl },
            React__default['default'].createElement("img", { src: logoSrc, alt: "Logo", height: logoHeight || 30 }))) : (React__default['default'].createElement(core.Avatar, { sx: { mb: 1, bgcolor: "primary.main" } },
            React__default['default'].createElement(icons.LoginOutlined, null)))),
        React__default['default'].createElement(core.Typography, { component: "h1", variant: "h2", sx: { textAlign: "center" } },
            React__default['default'].createElement(reactIntl.FormattedMessage, { id: titleKey || "pages.connect-title" })),
        React__default['default'].createElement(core.Typography, { component: "div", variant: "body2", sx: { textAlign: "center" } },
            React__default['default'].createElement(reactIntl.FormattedMessage, { id: subtitleKey || "pages.connect-subtitle" })),
        React__default['default'].createElement(core.Box, { component: "form", onSubmit: onSubmit, noValidate: true, sx: { mt: 1, width: "100%" } },
            React__default['default'].createElement(reactHookForm.Controller, { name: "email", rules: {
                    required: intl.formatMessage({ id: "pages.required-field" }),
                    pattern: { value: reactCrudComponents.EMAIL_REGEX, message: intl.formatMessage({ id: "pages.email-invalid" }) },
                }, control: control, defaultValue: "", render: function (_a) {
                    var _b;
                    var field = _a.field;
                    return (React__default['default'].createElement(core.TextField, { margin: "normal", required: true, fullWidth: true, label: intl.formatMessage({ id: "pages.email" }), value: field.value, type: "email", autoComplete: "email", autoFocus: true, onChange: function (e) {
                            field.onChange(e);
                            InputUtils.inputRemoveWhitespaces(e);
                        }, inputProps: {
                            maxLength: 50,
                        }, error: !!errors.email, helperText: (_b = errors === null || errors === void 0 ? void 0 : errors.email) === null || _b === void 0 ? void 0 : _b.message, ref: field.ref }));
                } }),
            React__default['default'].createElement(reactHookForm.Controller, { name: "password", rules: { required: intl.formatMessage({ id: "pages.required-field" }) }, control: control, defaultValue: "", render: function (_a) {
                    var _b;
                    var field = _a.field;
                    return (React__default['default'].createElement(core.TextField, { margin: "normal", required: true, fullWidth: true, label: intl.formatMessage({ id: "pages.password" }), value: field.value, type: "password", autoComplete: "current-password", onChange: function (e) {
                            field.onChange(e);
                            InputUtils.inputRemoveWhitespaces(e);
                        }, inputProps: {
                            maxLength: 30,
                        }, error: !!errors.password, helperText: (_b = errors === null || errors === void 0 ? void 0 : errors.password) === null || _b === void 0 ? void 0 : _b.message, ref: field.ref }));
                } }),
            React__default['default'].createElement(reactCrudComponents.StatusButton, { type: "submit", fullWidth: true, variant: "contained", sx: { mt: 2 }, loading: loginState.loading },
                React__default['default'].createElement(reactIntl.FormattedMessage, { id: "pages.connect" })))));
};

exports.LoginEmailPasswordCard = LoginEmailPasswordCard;
//# sourceMappingURL=index.js.map
